@@ -1,8 +1,11 @@
 """Main init for eboekhouden_python."""
 from .eboekhouden_client import EboekhoudenClient
+from . import models
+from . import constants
 
-
-__version__ = "0.1.7"
+__version__ = "0.1.8"
 __all__ = [
     "EboekhoudenClient",
+    "models",
+    "constants",
 ]
